import common_pb2 as _common_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class StartKernelRequest(_message.Message):
    __slots__ = ["kernel_name"]
    KERNEL_NAME_FIELD_NUMBER: _ClassVar[int]
    kernel_name: str
    def __init__(self, kernel_name: _Optional[str] = ...) -> None: ...

class StartKernelResponse(_message.Message):
    __slots__ = ["code", "msg"]
    CODE_FIELD_NUMBER: _ClassVar[int]
    MSG_FIELD_NUMBER: _ClassVar[int]
    code: int
    msg: str
    def __init__(self, code: _Optional[int] = ..., msg: _Optional[str] = ...) -> None: ...

class StopKernelRequest(_message.Message):
    __slots__ = ["kernel_name"]
    KERNEL_NAME_FIELD_NUMBER: _ClassVar[int]
    kernel_name: str
    def __init__(self, kernel_name: _Optional[str] = ...) -> None: ...

class StopKernelResponse(_message.Message):
    __slots__ = ["code", "msg"]
    CODE_FIELD_NUMBER: _ClassVar[int]
    MSG_FIELD_NUMBER: _ClassVar[int]
    code: int
    msg: str
    def __init__(self, code: _Optional[int] = ..., msg: _Optional[str] = ...) -> None: ...

class RestartKernelRequest(_message.Message):
    __slots__ = ["kernel_name"]
    KERNEL_NAME_FIELD_NUMBER: _ClassVar[int]
    kernel_name: str
    def __init__(self, kernel_name: _Optional[str] = ...) -> None: ...

class RestartKernelResponse(_message.Message):
    __slots__ = ["code", "msg"]
    CODE_FIELD_NUMBER: _ClassVar[int]
    MSG_FIELD_NUMBER: _ClassVar[int]
    code: int
    msg: str
    def __init__(self, code: _Optional[int] = ..., msg: _Optional[str] = ...) -> None: ...

class ExecuteRequest(_message.Message):
    __slots__ = ["code", "kernel_name"]
    CODE_FIELD_NUMBER: _ClassVar[int]
    KERNEL_NAME_FIELD_NUMBER: _ClassVar[int]
    code: str
    kernel_name: str
    def __init__(self, code: _Optional[str] = ..., kernel_name: _Optional[str] = ...) -> None: ...

class ExecuteResponse(_message.Message):
    __slots__ = ["output_type", "output"]
    class OutputType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        StdoutType: _ClassVar[ExecuteResponse.OutputType]
        StderrType: _ClassVar[ExecuteResponse.OutputType]
        ResultType: _ClassVar[ExecuteResponse.OutputType]
        TracebackType: _ClassVar[ExecuteResponse.OutputType]
    StdoutType: ExecuteResponse.OutputType
    StderrType: ExecuteResponse.OutputType
    ResultType: ExecuteResponse.OutputType
    TracebackType: ExecuteResponse.OutputType
    OUTPUT_TYPE_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_FIELD_NUMBER: _ClassVar[int]
    output_type: ExecuteResponse.OutputType
    output: str
    def __init__(self, output_type: _Optional[_Union[ExecuteResponse.OutputType, str]] = ..., output: _Optional[str] = ...) -> None: ...

class GetStatusRequest(_message.Message):
    __slots__ = ["kernel_name"]
    KERNEL_NAME_FIELD_NUMBER: _ClassVar[int]
    kernel_name: str
    def __init__(self, kernel_name: _Optional[str] = ...) -> None: ...

class GetStatusResponse(_message.Message):
    __slots__ = ["is_alive", "code", "msg"]
    IS_ALIVE_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    MSG_FIELD_NUMBER: _ClassVar[int]
    is_alive: bool
    code: int
    msg: str
    def __init__(self, is_alive: bool = ..., code: _Optional[int] = ..., msg: _Optional[str] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import agent_server_pb2 as agent__server__pb2
from . import common_pb2 as common__pb2


class AgentServerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ping = channel.unary_unary(
                '/octopus_agent_proto.AgentServer/ping',
                request_serializer=agent__server__pb2.PingRequest.SerializeToString,
                response_deserializer=agent__server__pb2.PongResponse.FromString,
                )
        self.upload = channel.stream_unary(
                '/octopus_agent_proto.AgentServer/upload',
                request_serializer=common__pb2.FileChunk.SerializeToString,
                response_deserializer=common__pb2.FileUploaded.FromString,
                )
        self.download = channel.unary_stream(
                '/octopus_agent_proto.AgentServer/download',
                request_serializer=common__pb2.DownloadRequest.SerializeToString,
                response_deserializer=common__pb2.FileChunk.FromString,
                )
        self.send_task = channel.unary_stream(
                '/octopus_agent_proto.AgentServer/send_task',
                request_serializer=agent__server__pb2.SendTaskRequest.SerializeToString,
                response_deserializer=agent__server__pb2.TaskRespond.FromString,
                )
        self.add_kernel = channel.unary_unary(
                '/octopus_agent_proto.AgentServer/add_kernel',
                request_serializer=agent__server__pb2.AddKernelRequest.SerializeToString,
                response_deserializer=agent__server__pb2.AddKernelResponse.FromString,
                )
        self.assemble = channel.unary_unary(
                '/octopus_agent_proto.AgentServer/assemble',
                request_serializer=agent__server__pb2.AssembleAppRequest.SerializeToString,
                response_deserializer=agent__server__pb2.AssembleAppResponse.FromString,
                )
        self.run = channel.unary_stream(
                '/octopus_agent_proto.AgentServer/run',
                request_serializer=agent__server__pb2.RunAppRequest.SerializeToString,
                response_deserializer=agent__server__pb2.TaskRespond.FromString,
                )
        self.query_apps = channel.unary_unary(
                '/octopus_agent_proto.AgentServer/query_apps',
                request_serializer=agent__server__pb2.QueryAppsRequest.SerializeToString,
                response_deserializer=agent__server__pb2.QueryAppsResponse.FromString,
                )


class AgentServerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ping(self, request, context):
        """check the connection is ok
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def upload(self, request_iterator, context):
        """upload the file
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def download(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def send_task(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def add_kernel(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def assemble(self, request, context):
        """assemble the application
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def run(self, request, context):
        """run assembled application
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def query_apps(self, request, context):
        """query all apps
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AgentServerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ping': grpc.unary_unary_rpc_method_handler(
                    servicer.ping,
                    request_deserializer=agent__server__pb2.PingRequest.FromString,
                    response_serializer=agent__server__pb2.PongResponse.SerializeToString,
            ),
            'upload': grpc.stream_unary_rpc_method_handler(
                    servicer.upload,
                    request_deserializer=common__pb2.FileChunk.FromString,
                    response_serializer=common__pb2.FileUploaded.SerializeToString,
            ),
            'download': grpc.unary_stream_rpc_method_handler(
                    servicer.download,
                    request_deserializer=common__pb2.DownloadRequest.FromString,
                    response_serializer=common__pb2.FileChunk.SerializeToString,
            ),
            'send_task': grpc.unary_stream_rpc_method_handler(
                    servicer.send_task,
                    request_deserializer=agent__server__pb2.SendTaskRequest.FromString,
                    response_serializer=agent__server__pb2.TaskRespond.SerializeToString,
            ),
            'add_kernel': grpc.unary_unary_rpc_method_handler(
                    servicer.add_kernel,
                    request_deserializer=agent__server__pb2.AddKernelRequest.FromString,
                    response_serializer=agent__server__pb2.AddKernelResponse.SerializeToString,
            ),
            'assemble': grpc.unary_unary_rpc_method_handler(
                    servicer.assemble,
                    request_deserializer=agent__server__pb2.AssembleAppRequest.FromString,
                    response_serializer=agent__server__pb2.AssembleAppResponse.SerializeToString,
            ),
            'run': grpc.unary_stream_rpc_method_handler(
                    servicer.run,
                    request_deserializer=agent__server__pb2.RunAppRequest.FromString,
                    response_serializer=agent__server__pb2.TaskRespond.SerializeToString,
            ),
            'query_apps': grpc.unary_unary_rpc_method_handler(
                    servicer.query_apps,
                    request_deserializer=agent__server__pb2.QueryAppsRequest.FromString,
                    response_serializer=agent__server__pb2.QueryAppsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'octopus_agent_proto.AgentServer', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AgentServer(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ping(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/octopus_agent_proto.AgentServer/ping',
            agent__server__pb2.PingRequest.SerializeToString,
            agent__server__pb2.PongResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def upload(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/octopus_agent_proto.AgentServer/upload',
            common__pb2.FileChunk.SerializeToString,
            common__pb2.FileUploaded.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def download(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/octopus_agent_proto.AgentServer/download',
            common__pb2.DownloadRequest.SerializeToString,
            common__pb2.FileChunk.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def send_task(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/octopus_agent_proto.AgentServer/send_task',
            agent__server__pb2.SendTaskRequest.SerializeToString,
            agent__server__pb2.TaskRespond.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def add_kernel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/octopus_agent_proto.AgentServer/add_kernel',
            agent__server__pb2.AddKernelRequest.SerializeToString,
            agent__server__pb2.AddKernelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def assemble(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/octopus_agent_proto.AgentServer/assemble',
            agent__server__pb2.AssembleAppRequest.SerializeToString,
            agent__server__pb2.AssembleAppResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def run(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/octopus_agent_proto.AgentServer/run',
            agent__server__pb2.RunAppRequest.SerializeToString,
            agent__server__pb2.TaskRespond.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def query_apps(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/octopus_agent_proto.AgentServer/query_apps',
            agent__server__pb2.QueryAppsRequest.SerializeToString,
            agent__server__pb2.QueryAppsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class FileChunk(_message.Message):
    __slots__ = ["buffer", "filename"]
    BUFFER_FIELD_NUMBER: _ClassVar[int]
    FILENAME_FIELD_NUMBER: _ClassVar[int]
    buffer: bytes
    filename: str
    def __init__(self, buffer: _Optional[bytes] = ..., filename: _Optional[str] = ...) -> None: ...

class FileUploaded(_message.Message):
    __slots__ = ["length"]
    LENGTH_FIELD_NUMBER: _ClassVar[int]
    length: int
    def __init__(self, length: _Optional[int] = ...) -> None: ...

class DownloadRequest(_message.Message):
    __slots__ = ["filename"]
    FILENAME_FIELD_NUMBER: _ClassVar[int]
    filename: str
    def __init__(self, filename: _Optional[str] = ...) -> None: ...



import common_pb2 as _common_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SendTaskRequest(_message.Message):
    __slots__ = ["input_files", "task"]
    INPUT_FILES_FIELD_NUMBER: _ClassVar[int]
    TASK_FIELD_NUMBER: _ClassVar[int]
    input_files: _containers.RepeatedScalarFieldContainer[str]
    task: str
    def __init__(self, input_files: _Optional[_Iterable[str]] = ..., task: _Optional[str] = ...) -> None: ...

class OnAgentAction(_message.Message):
    __slots__ = ["input", "tool"]
    INPUT_FIELD_NUMBER: _ClassVar[int]
    TOOL_FIELD_NUMBER: _ClassVar[int]
    input: str
    tool: str
    def __init__(self, input: _Optional[str] = ..., tool: _Optional[str] = ...) -> None: ...

class OnAgentActionEnd(_message.Message):
    __slots__ = ["output", "output_files", "has_error"]
    OUTPUT_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_FILES_FIELD_NUMBER: _ClassVar[int]
    HAS_ERROR_FIELD_NUMBER: _ClassVar[int]
    output: str
    output_files: _containers.RepeatedScalarFieldContainer[str]
    has_error: bool
    def __init__(self, output: _Optional[str] = ..., output_files: _Optional[_Iterable[str]] = ..., has_error: bool = ...) -> None: ...

class FinalRespond(_message.Message):
    __slots__ = ["answer"]
    ANSWER_FIELD_NUMBER: _ClassVar[int]
    answer: str
    def __init__(self, answer: _Optional[str] = ...) -> None: ...

class TaskState(_message.Message):
    __slots__ = ["generated_token_count", "iteration_count", "model_name", "total_duration", "sent_token_count", "model_respond_duration"]
    GENERATED_TOKEN_COUNT_FIELD_NUMBER: _ClassVar[int]
    ITERATION_COUNT_FIELD_NUMBER: _ClassVar[int]
    MODEL_NAME_FIELD_NUMBER: _ClassVar[int]
    TOTAL_DURATION_FIELD_NUMBER: _ClassVar[int]
    SENT_TOKEN_COUNT_FIELD_NUMBER: _ClassVar[int]
    MODEL_RESPOND_DURATION_FIELD_NUMBER: _ClassVar[int]
    generated_token_count: int
    iteration_count: int
    model_name: str
    total_duration: int
    sent_token_count: int
    model_respond_duration: int
    def __init__(self, generated_token_count: _Optional[int] = ..., iteration_count: _Optional[int] = ..., model_name: _Optional[str] = ..., total_duration: _Optional[int] = ..., sent_token_count: _Optional[int] = ..., model_respond_duration: _Optional[int] = ...) -> None: ...

class TaskRespond(_message.Message):
    __slots__ = ["state", "respond_type", "on_agent_action", "on_agent_action_end", "final_respond", "console_stdout", "console_stderr", "typing_content"]
    class RespondType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        OnAgentActionType: _ClassVar[TaskRespond.RespondType]
        OnAgentActionStdout: _ClassVar[TaskRespond.RespondType]
        OnAgentActionStderr: _ClassVar[TaskRespond.RespondType]
        OnAgentActionEndType: _ClassVar[TaskRespond.RespondType]
        OnFinalAnswerType: _ClassVar[TaskRespond.RespondType]
        OnAgentTextTyping: _ClassVar[TaskRespond.RespondType]
        OnAgentCodeTyping: _ClassVar[TaskRespond.RespondType]
    OnAgentActionType: TaskRespond.RespondType
    OnAgentActionStdout: TaskRespond.RespondType
    OnAgentActionStderr: TaskRespond.RespondType
    OnAgentActionEndType: TaskRespond.RespondType
    OnFinalAnswerType: TaskRespond.RespondType
    OnAgentTextTyping: TaskRespond.RespondType
    OnAgentCodeTyping: TaskRespond.RespondType
    STATE_FIELD_NUMBER: _ClassVar[int]
    RESPOND_TYPE_FIELD_NUMBER: _ClassVar[int]
    ON_AGENT_ACTION_FIELD_NUMBER: _ClassVar[int]
    ON_AGENT_ACTION_END_FIELD_NUMBER: _ClassVar[int]
    FINAL_RESPOND_FIELD_NUMBER: _ClassVar[int]
    CONSOLE_STDOUT_FIELD_NUMBER: _ClassVar[int]
    CONSOLE_STDERR_FIELD_NUMBER: _ClassVar[int]
    TYPING_CONTENT_FIELD_NUMBER: _ClassVar[int]
    state: TaskState
    respond_type: TaskRespond.RespondType
    on_agent_action: OnAgentAction
    on_agent_action_end: OnAgentActionEnd
    final_respond: FinalRespond
    console_stdout: str
    console_stderr: str
    typing_content: str
    def __init__(self, state: _Optional[_Union[TaskState, _Mapping]] = ..., respond_type: _Optional[_Union[TaskRespond.RespondType, str]] = ..., on_agent_action: _Optional[_Union[OnAgentAction, _Mapping]] = ..., on_agent_action_end: _Optional[_Union[OnAgentActionEnd, _Mapping]] = ..., final_respond: _Optional[_Union[FinalRespond, _Mapping]] = ..., console_stdout: _Optional[str] = ..., console_stderr: _Optional[str] = ..., typing_content: _Optional[str] = ...) -> None: ...

class AddKernelRequest(_message.Message):
    __slots__ = ["endpoint", "key"]
    ENDPOINT_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    endpoint: str
    key: str
    def __init__(self, endpoint: _Optional[str] = ..., key: _Optional[str] = ...) -> None: ...

class AddKernelResponse(_message.Message):
    __slots__ = ["code", "msg"]
    CODE_FIELD_NUMBER: _ClassVar[int]
    MSG_FIELD_NUMBER: _ClassVar[int]
    code: int
    msg: str
    def __init__(self, code: _Optional[int] = ..., msg: _Optional[str] = ...) -> None: ...

class AssembleAppRequest(_message.Message):
    __slots__ = ["name", "language", "code", "saved_filenames", "desc"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    LANGUAGE_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    SAVED_FILENAMES_FIELD_NUMBER: _ClassVar[int]
    DESC_FIELD_NUMBER: _ClassVar[int]
    name: str
    language: str
    code: str
    saved_filenames: _containers.RepeatedScalarFieldContainer[str]
    desc: str
    def __init__(self, name: _Optional[str] = ..., language: _Optional[str] = ..., code: _Optional[str] = ..., saved_filenames: _Optional[_Iterable[str]] = ..., desc: _Optional[str] = ...) -> None: ...

class AssembleAppResponse(_message.Message):
    __slots__ = ["code", "msg"]
    CODE_FIELD_NUMBER: _ClassVar[int]
    MSG_FIELD_NUMBER: _ClassVar[int]
    code: int
    msg: str
    def __init__(self, code: _Optional[int] = ..., msg: _Optional[str] = ...) -> None: ...

class RunAppRequest(_message.Message):
    __slots__ = ["name"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class AppInfo(_message.Message):
    __slots__ = ["name", "language", "ctime", "desc"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    LANGUAGE_FIELD_NUMBER: _ClassVar[int]
    CTIME_FIELD_NUMBER: _ClassVar[int]
    DESC_FIELD_NUMBER: _ClassVar[int]
    name: str
    language: str
    ctime: int
    desc: str
    def __init__(self, name: _Optional[str] = ..., language: _Optional[str] = ..., ctime: _Optional[int] = ..., desc: _Optional[str] = ...) -> None: ...

class QueryAppsRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class QueryAppsResponse(_message.Message):
    __slots__ = ["apps"]
    APPS_FIELD_NUMBER: _ClassVar[int]
    apps: _containers.RepeatedCompositeFieldContainer[AppInfo]
    def __init__(self, apps: _Optional[_Iterable[_Union[AppInfo, _Mapping]]] = ...) -> None: ...

class PingRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class PongResponse(_message.Message):
    __slots__ = ["code", "msg"]
    CODE_FIELD_NUMBER: _ClassVar[int]
    MSG_FIELD_NUMBER: _ClassVar[int]
    code: int
    msg: str
    def __init__(self, code: _Optional[int] = ..., msg: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kernel_server.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13kernel_server.proto\x12\x14octopus_kernel_proto\x1a\x0c\x63ommon.proto\")\n\x12StartKernelRequest\x12\x13\n\x0bkernel_name\x18\x01 \x01(\t\"0\n\x13StartKernelResponse\x12\x0c\n\x04\x63ode\x18\x02 \x01(\x05\x12\x0b\n\x03msg\x18\x03 \x01(\t\"(\n\x11StopKernelRequest\x12\x13\n\x0bkernel_name\x18\x01 \x01(\t\"/\n\x12StopKernelResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\"+\n\x14RestartKernelRequest\x12\x13\n\x0bkernel_name\x18\x01 \x01(\t\"2\n\x15RestartKernelResponse\x12\x0c\n\x04\x63ode\x18\x02 \x01(\x05\x12\x0b\n\x03msg\x18\x03 \x01(\t\"3\n\x0e\x45xecuteRequest\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x13\n\x0bkernel_name\x18\x02 \x01(\t\"\xb9\x01\n\x0f\x45xecuteResponse\x12\x45\n\x0boutput_type\x18\x01 \x01(\x0e\x32\x30.octopus_kernel_proto.ExecuteResponse.OutputType\x12\x0e\n\x06output\x18\x02 \x01(\t\"O\n\nOutputType\x12\x0e\n\nStdoutType\x10\x00\x12\x0e\n\nStderrType\x10\x01\x12\x0e\n\nResultType\x10\x02\x12\x11\n\rTracebackType\x10\x03\"\'\n\x10GetStatusRequest\x12\x13\n\x0bkernel_name\x18\x01 \x01(\t\"@\n\x11GetStatusResponse\x12\x10\n\x08is_alive\x18\x01 \x01(\x08\x12\x0c\n\x04\x63ode\x18\x02 \x01(\x05\x12\x0b\n\x03msg\x18\x03 \x01(\t2\xb7\x04\n\x10KernelServerNode\x12^\n\x05start\x12(.octopus_kernel_proto.StartKernelRequest\x1a).octopus_kernel_proto.StartKernelResponse\"\x00\x12[\n\x04stop\x12\'.octopus_kernel_proto.StopKernelRequest\x1a(.octopus_kernel_proto.StopKernelResponse\"\x00\x12Z\n\x07\x65xecute\x12$.octopus_kernel_proto.ExecuteRequest\x1a%.octopus_kernel_proto.ExecuteResponse\"\x00\x30\x01\x12_\n\nget_status\x12&.octopus_kernel_proto.GetStatusRequest\x1a\'.octopus_kernel_proto.GetStatusResponse\"\x00\x12Q\n\x06upload\x12\x1f.octopus_common_proto.FileChunk\x1a\".octopus_common_proto.FileUploaded\"\x00(\x01\x12V\n\x08\x64ownload\x12%.octopus_common_proto.DownloadRequest\x1a\x1f.octopus_common_proto.FileChunk\"\x00\x30\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'kernel_server_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_STARTKERNELREQUEST']._serialized_start=59
  _globals['_STARTKERNELREQUEST']._serialized_end=100
  _globals['_STARTKERNELRESPONSE']._serialized_start=102
  _globals['_STARTKERNELRESPONSE']._serialized_end=150
  _globals['_STOPKERNELREQUEST']._serialized_start=152
  _globals['_STOPKERNELREQUEST']._serialized_end=192
  _globals['_STOPKERNELRESPONSE']._serialized_start=194
  _globals['_STOPKERNELRESPONSE']._serialized_end=241
  _globals['_RESTARTKERNELREQUEST']._serialized_start=243
  _globals['_RESTARTKERNELREQUEST']._serialized_end=286
  _globals['_RESTARTKERNELRESPONSE']._serialized_start=288
  _globals['_RESTARTKERNELRESPONSE']._serialized_end=338
  _globals['_EXECUTEREQUEST']._serialized_start=340
  _globals['_EXECUTEREQUEST']._serialized_end=391
  _globals['_EXECUTERESPONSE']._serialized_start=394
  _globals['_EXECUTERESPONSE']._serialized_end=579
  _globals['_EXECUTERESPONSE_OUTPUTTYPE']._serialized_start=500
  _globals['_EXECUTERESPONSE_OUTPUTTYPE']._serialized_end=579
  _globals['_GETSTATUSREQUEST']._serialized_start=581
  _globals['_GETSTATUSREQUEST']._serialized_end=620
  _globals['_GETSTATUSRESPONSE']._serialized_start=622
  _globals['_GETSTATUSRESPONSE']._serialized_end=686
  _globals['_KERNELSERVERNODE']._serialized_start=689
  _globals['_KERNELSERVERNODE']._serialized_end=1256
# @@protoc_insertion_point(module_scope)
